searchData={"items":[{"type":"module","title":"Ueberauth.Strategy.Atlassian","doc":"","ref":"Ueberauth.Strategy.Atlassian.html"},{"type":"module","title":"Installation - Ueberauth.Strategy.Atlassian","doc":"1.  Setup your application at [Atlassian Developer Console](https://developer.atlassian.com/console/myapps/).\n\n2.  Add `:ueberauth_atlassian` to your list of dependencies in `mix.exs`:\n\n    ```elixir\n    def deps do\n      [\n        {:ueberauth_atlassian, \"~> 0.1.0\"}\n      ]\n    end\n    ```\n\n3.  Add Atlassian to your Überauth configuration:\n\n    ```elixir\n    config :ueberauth, Ueberauth,\n      providers: [\n        atlassian: {Ueberauth.Strategy.Atlassian, []}\n      ]\n    ```\n\n4.  Update your provider configuration:\n\n    Use that if you want to read client ID/secret from the environment\n    variables in the compile time:\n\n    ```elixir\n    config :ueberauth, Ueberauth.Strategy.Atlassian.OAuth,\n      client_id: System.get_env(\"ATLASSIAN_CLIENT_ID\"),\n      client_secret: System.get_env(\"ATLASSIAN_CLIENT_SECRET\")\n    ```\n\n    Use that if you want to read client ID/secret from the environment\n    variables in the run time:\n\n    ```elixir\n    config :ueberauth, Ueberauth.Strategy.Atlassian.OAuth,\n      client_id: {System, :get_env, [\"ATLASSIAN_CLIENT_ID\"]},\n      client_secret: {System, :get_env, [\"ATLASSIAN_CLIENT_SECRET\"]}\n    ```\n\n5.  Include the Überauth plug in your controller:\n\n    ```elixir\n    defmodule MyApp.AuthController do\n      use MyApp.Web, :controller\n      plug Ueberauth\n      ...\n    end\n    ```\n\n6.  Create the request and callback routes if you haven't already:\n\n    ```elixir\n    scope \"/auth\", MyApp do\n      pipe_through :browser\n\n      get \"/:provider\", AuthController, :request\n      get \"/:provider/callback\", AuthController, :callback\n    end\n    ```\n\n7.  Your controller needs to implement callbacks to deal with `Ueberauth.Auth` and `Ueberauth.Failure` responses.\n\nFor an example implementation see the [Überauth Example](https://github.com/ueberauth/ueberauth_example) application.","ref":"Ueberauth.Strategy.Atlassian.html#module-installation"},{"type":"module","title":"Calling - Ueberauth.Strategy.Atlassian","doc":"Depending on the configured url you can initiate the request through:\n\n    /auth/atlassian\n\nOr with options:\n\n    /auth/atlassian?scope=read%3Ame%20read%3Ajira-work\n\nBy default the requested scope is \"read:me offline_access\". Scope can be configured either explicitly as a `scope` query value on the request path or in your configuration:\n\n```elixir\nconfig :ueberauth, Ueberauth,\n  providers: [\n    atlassian: {Ueberauth.Strategy.Atlassian, [default_scope: \"read:me offline_access\"]}\n  ]\n```","ref":"Ueberauth.Strategy.Atlassian.html#module-calling"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.credentials/1","doc":"Gets called after handle_callback! to set the credentials struct with the token information","ref":"Ueberauth.Strategy.Atlassian.html#credentials/1"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.default_options/0","doc":"","ref":"Ueberauth.Strategy.Atlassian.html#default_options/0"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.extra/1","doc":"","ref":"Ueberauth.Strategy.Atlassian.html#extra/1"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.handle_callback!/1","doc":"This function will be called by your auth controller callback handler.\nThe user is forwarded to the callback after authentication on Atlassian.\nThe function retrieves the access token and fetches the user details.","ref":"Ueberauth.Strategy.Atlassian.html#handle_callback!/1"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.handle_cleanup!/1","doc":"Cleanup user information on logout.","ref":"Ueberauth.Strategy.Atlassian.html#handle_cleanup!/1"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.handle_refresh!/2","doc":"The function retrieves exchanges a refresh token for an access token.","ref":"Ueberauth.Strategy.Atlassian.html#handle_refresh!/2"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.handle_request!/1","doc":"This function will be called by your auth controller request handler.\nIt forwards the user to Atlassian for authentication in return it passes back a code to the callback.","ref":"Ueberauth.Strategy.Atlassian.html#handle_request!/1"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.info/1","doc":"Fetches the fields to populate the info section of the `Ueberauth.Auth` struct.","ref":"Ueberauth.Strategy.Atlassian.html#info/1"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.uid/1","doc":"Fetches the uid field from the response.","ref":"Ueberauth.Strategy.Atlassian.html#uid/1"},{"type":"module","title":"Ueberauth.Strategy.Atlassian.OAuth","doc":"Ueberauth strategy to authenticate via Atlassian.","ref":"Ueberauth.Strategy.Atlassian.OAuth.html"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.OAuth.authorize_url/2","doc":"","ref":"Ueberauth.Strategy.Atlassian.OAuth.html#authorize_url/2"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.OAuth.authorize_url!/2","doc":"","ref":"Ueberauth.Strategy.Atlassian.OAuth.html#authorize_url!/2"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.OAuth.client/1","doc":"Create a preconfigured OAuth2.Client","ref":"Ueberauth.Strategy.Atlassian.OAuth.html#client/1"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.OAuth.get/4","doc":"Access a url authenticating with the given token","ref":"Ueberauth.Strategy.Atlassian.OAuth.html#get/4"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.OAuth.get_access_token/2","doc":"Retrieves an access token by calling https://auth.atlassian.com or returns an error\n\n    ```\n    curl --request POST\n    --url 'https://auth.atlassian.com/oauth/token'\n    --header 'Content-Type: application/json'\n    --data '{\"grant_type\": \"authorization_code\",\n      \"client_id\": \"YOUR_CLIENT_ID\",\n      \"client_secret\": \"YOUR_CLIENT_SECRET\",\n      \"code\": \"YOUR_AUTHORIZATION_CODE\",\n      \"redirect_uri\": \"https://YOUR_APP_CALLBACK_URL\"}'\n    ```","ref":"Ueberauth.Strategy.Atlassian.OAuth.html#get_access_token/2"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.OAuth.get_token/3","doc":"","ref":"Ueberauth.Strategy.Atlassian.OAuth.html#get_token/3"},{"type":"function","title":"Ueberauth.Strategy.Atlassian.OAuth.refresh_access_token/1","doc":"Exchange your refresh token for a new access token.\n```\ncurl --request POST\n  --url 'https://auth.atlassian.com/oauth/token'\n  --header 'Content-Type: application/json'\n  --data '{ \"grant_type\": \"refresh_token\",\n            \"client_id\": \"YOUR_CLIENT_ID\",\n            \"client_secret\": \"YOUR_CLIENT_SECRET\",\n            \"refresh_token\": \"YOUR_REFRESH_TOKEN\" }'\n```","ref":"Ueberauth.Strategy.Atlassian.OAuth.html#refresh_access_token/1"}],"content_type":"text/markdown"}